@@ -3,7 +3,6 @@ from time import time
 
 from gdbn.dbn import buildDBN
 from gdbn import activationFunctions
-import gnumpy
 import numpy as np
 from sklearn.base import BaseEstimator
 
@@ -14,12 +13,12 @@ class DBN(BaseEstimator):
     """
     def __init__(
         self,
-        layer_sizes,
+        layer_sizes=None,
         scales=0.05,
         fan_outs=None,
         output_act_funct=None,
         real_valued_vis=True,
-        use_re_lu=False,
+        use_re_lu=True,
         uniforms=False,
 
         learn_rates=0.1,
@@ -28,7 +27,7 @@ class DBN(BaseEstimator):
         momentum=0.9,
         l2_costs=0.0001,
         dropouts=0,
-        nesterov=False,
+        nesterov=True,
         nest_compare=True,
         rms_lims=None,
 
@@ -78,9 +77,15 @@ class DBN(BaseEstimator):
                             if you pass an ``X`` with 784 features,
                             and a ``y`` with 10 classes.
 
-        :param scales: Not documented at this time.
+        :param scales: Scale of the randomly initialized weights.  A
+                       list of floating point values.  When you find
+                       good values for the scale of the weights you
+                       can speed up training a lot, and also improve
+                       performance.  Defaults to `0.05`.
 
-        :param fan_outs: Not documented at this time.
+        :param fan_outs: Number of nonzero incoming connections to a
+                         hidden unit.  Defaults to `None`, which means
+                         that all connections have non-zero weights.
 
         :param output_act_funct: Output activation function.  Instance
                                  of type
@@ -169,6 +174,9 @@ class DBN(BaseEstimator):
         :param verbose: Debugging output.
         """
 
+        if layer_sizes is None:
+            layer_sizes = [-1, -1]
+
         if output_act_funct is None:
             output_act_funct = activationFunctions.Softmax()
         elif isinstance(output_act_funct, str):
@@ -208,6 +216,13 @@ class DBN(BaseEstimator):
         self.fine_tune_callback = fine_tune_callback
         self.verbose = verbose
 
+    def _fill_missing_layer_sizes(self, X, y):
+        layer_sizes = self.layer_sizes
+        if layer_sizes[0] == -1:  # n_feat
+            layer_sizes[0] = X.shape[1]
+        if layer_sizes[-1] == -1 and y is not None:  # n_classes
+            layer_sizes[-1] = y.shape[1]
+
     def _vp(self, value):
         num_weights = len(self.layer_sizes) - 1
         if not hasattr(value, '__iter__'):
@@ -217,17 +232,12 @@ class DBN(BaseEstimator):
     def _build_net(self, X, y=None):
         v = self._vp
 
-        layer_sizes = list(self.layer_sizes)
-        if layer_sizes[0] == -1:  # n_feat
-            layer_sizes[0] = X.shape[1]
-        if layer_sizes[-1] == -1 and y is not None:  # n_classes
-            layer_sizes[-1] = y.shape[1]
-
+        self._fill_missing_layer_sizes(X, y)
         if self.verbose:  # pragma: no cover
-            print "[DBN] layers {}".format(layer_sizes)
+            print "[DBN] layers {}".format(self.layer_sizes)
 
         net = buildDBN(
-            layer_sizes,
+            self.layer_sizes,
             v(self.scales),
             v(self.fan_outs),
             self.output_act_funct,
@@ -323,6 +333,8 @@ class DBN(BaseEstimator):
             print "Learn rates: {}".format(self.net_.learnRates)
 
     def fit(self, X, y):
+        if self.verbose:
+            print "[DBN] fitting X.shape=%s" % (X.shape,)
         y = self._onehot(y)
 
         self.net_ = self._build_net(X, y)
@@ -361,7 +373,8 @@ class DBN(BaseEstimator):
                         print "  ({})".format(elapsed.split('.')[0])
                         time0 = time()
                     if self.pretrain_callback is not None:
-                        self.pretrain_callback(self, epoch, layer_index)
+                        self.pretrain_callback(
+                            self, epoch + 1, layer_index)
 
         self._configure_net_finetune(self.net_)
         if self.verbose:  # pragma: no cover
@@ -387,7 +400,7 @@ class DBN(BaseEstimator):
                 print "  ({})".format(elapsed.split('.')[0])
                 time0 = time()
             if self.fine_tune_callback is not None:
-                self.fine_tune_callback(self, epoch)
+                self.fine_tune_callback(self, epoch + 1)
 
     def predict(self, X):
         return np.argmax(self.predict_proba(X), axis=1)
@@ -417,3 +430,4 @@ class DBN(BaseEstimator):
         targets = self._onehot(y)
         mistakes = loss_funct(outputs, targets)
         return - float(mistakes) / len(y) + 1
+
